@@ -1,17 +1,17 @@
 //! Custom error types.
 
-use crate::process_ext::ChildExtError;
 use std::io;
 use std::path::PathBuf;
 use std::process::ExitStatus;
 use thiserror::Error;
 
+#[allow(dead_code)]
 #[derive(Debug, Error)]
 /// Error arising in the `workflow` and `main` module.
 pub enum WorkflowError {
     /// Remedy: check <path> to note file.
     #[error("Can not export. No note file found.")]
-    ExportsNeedsNoteFile,
+    ExportNeedsNoteFile,
 
     /// Remedy: restart with `--debug trace`.
     #[error("Failed to render template (cf. `{tmpl_name}` in configuration file)!\n{source}")]
@@ -26,6 +26,9 @@ pub enum WorkflowError {
     #[error(transparent)]
     MissingFrontMatterField { source: NoteError },
 
+    #[error(transparent)]
+    CompulsoryFrontMatterFieldIsEmpty { source: NoteError },
+
     #[error(transparent)]
     InvalidFrontMatterYaml { source: NoteError },
 
@@ -142,14 +145,6 @@ pub enum FileError {
     #[error("Can not convert path to UFT8:\n{path:?}")]
     PathNotUtf8 { path: PathBuf },
 
-    /// Remedy: check the configuration file variables `[app_args] editor`
-    /// and `[app_args] browser`.
-    #[error("Error executing external application:")]
-    ChildExt {
-        #[from]
-        source: ChildExtError,
-    },
-
     /// Remedy: check the configuration file variable `[app_args] editor`.
     #[error(
         "The external application did not terminate gracefully: {code}\n\
@@ -244,6 +239,10 @@ pub enum NoteError {
     )]
     MissingFrontMatterField { field_name: String },
 
+    /// Remedy: enter a string.
+    #[error("The value of the front matter field `{field_name}:` must be a non empty string.")]
+    CompulsoryFrontMatterFieldIsEmpty { field_name: String },
+
     /// Remedy: check YAML syntax in the note's front matter.
     #[error(
         "Can not parse front matter:\n\
@@ -316,7 +315,7 @@ pub enum NoteError {
         \t{txt_ext:?}\n\
         \t{no_viewer_ext:?}\n\
         \n\
-        Choose one of the above list or add more extensions to the\n\
+        Choose one of the listed above or add more extensions to the\n\
         `[filename] extensions_*` variables in your configuration file."
     )]
     FileExtNotRegistered {
